/*-------------------------------------------------------------------------
 * Copyright (c) 1998 Kenneth W. Sodemann (stufflehead@bigfoot.com)
 *-------------------------------------------------------------------------
 * msgs.c
 *
 * Routines used to output error messages.
 *
 * $Log: msgs.c,v $
 * Revision 1.3  1998/07/24 20:23:48  kwsodema
 * Added display_fan_on and display_fan_off.  Removed the display_msg
 * function.
 *
 * Revision 1.2  1998/07/22 20:36:14  kwsodema
 * Added the display_msg function.  Remove extra \n from
 * the display_version function.
 *
 * Revision 1.1  1998/07/21 21:46:15  kwsodema
 * Initial revision
 *
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *-------------------------------------------------------------------------
 */

#include "common.h"
#include "msgs.h"
#include <assert.h>
#include <string.h>
#include <stdio.h>

/*-------------------------------------------------------------------------
 * Defined errors.
 *-------------------------------------------------------------------------
 */
#define IO_PERM_STRING "Cannot get I/O permissions."
#define INV_ARGS_STRING "Inavlid argument:"
#define UNK_ERR_STRING "Unknown error."
#define FAN_ON_STRING "The fan is on."
#define FAN_OFF_STRING "The fan is off."

/*-------------------------------------------------------------------------
 * dump_error_msg
 *
 * Dumps the error message for a known class of error out to the
 * error stream, appending msg to the end of the canned error message.
 *-------------------------------------------------------------------------
 */
void dump_error_msg (error_type err, char *msg)
{
  switch (err)
    {
    case io_perms:
      if (msg != NULL)
	{
	  fprintf (stderr, "%s: %s %s\n", 
		   PROG_NAME, IO_PERM_STRING, msg);
	}
      else
	{
	  fprintf (stderr, "%s: %s\n", 
		   PROG_NAME, IO_PERM_STRING);
	}
      break;

    case invld_args:
      if (msg != NULL)
	{
	  fprintf (stderr, "%s: %s %s\n%s\n", 
	       PROG_NAME, INV_ARGS_STRING, msg, USAGE_STR);
	}
      else
	{
	  fprintf (stderr, "%s: %s \n%s\n", 
	       PROG_NAME, INV_ARGS_STRING, USAGE_STR);
	}
      break;
	       
    case blank_err:
      if (msg != NULL)
	{
	  fprintf (stderr, "%s: %s\n", 
		   PROG_NAME, msg);
	}

      break;

    default:
      if (msg != NULL)
	{
	  fprintf (stderr, "%s: %s %s\n",
		   PROG_NAME, UNK_ERR_STRING, msg);
	}
      else
	{
	  fprintf (stderr, "%s: %s\n",
		   PROG_NAME, UNK_ERR_STRING);
	}
    }
}

/*-------------------------------------------------------------------------
 * display_version
 *
 * Display the version message.
 *-------------------------------------------------------------------------
 */
void display_version (void)
{
  printf ("%s\n", VERSION);
}

/*-------------------------------------------------------------------------
 * display_help
 *
 * Display the help message.
 *-------------------------------------------------------------------------
 */
void display_help (void)
{
  printf ("\n%s\n", USAGE_STR);
}

/*-------------------------------------------------------------------------
 * display_fan_on
 *
 * Display the fan on message.
 *-------------------------------------------------------------------------
 */
void display_fan_on (void)
{
  printf ("%s\n", FAN_ON_STRING);
}

/*-------------------------------------------------------------------------
 * display_fan_off
 *
 * Display the fan off message.
 *-------------------------------------------------------------------------
 */
void display_fan_off (void)
{
  printf ("%s\n", FAN_OFF_STRING);
}
